@@ -559,13 +559,13 @@ duration_to_seconds (const gchar *str)
 static gboolean
 mime_is_video (const gchar *mime)
 {
-  return mime && strstr (mime, "video") != NULL;
+  return mime && g_str_has_prefix (mime, "video/");
 }
 
 static gboolean
 mime_is_audio (const gchar *mime)
 {
-  return mime && strstr (mime, "audio") != NULL;
+  return mime && g_str_has_prefix (mime, "audio/");
 }
 
 static gchar *
